class Distibution:
    def __init__(self, mu = 0, sigma = 1 ):
        self.mean = mu
        self.stddev = sigma
        self.data = []
            
    def readthefile(self, filename):
        print("Read function")
        data_set = []
        with open(filename) as fl:
            for lines in fl:
                data_set.append(int(lines.strip()))
        self.data = data_set
        
    def show(self):
        print(self.data)    


from setuptools import setup

setup(name='distributiongaussian',
      version='1.0',
      description='package of distribution and gausssian py',
      packages=['distributiongaussian'],
      zip_safe=False)

# Set-ExecutionPolicy -Scope CurrentUser -ExecutionPolicy Unrestricted


from .distibution import Distibution

class Gaussian(Distibution):
    def __init__(self, mu = 0, sigma = 1 ):
        Distibution.__init__(self, mu, sigma)
        
    def calculate_mean(self):
        """ calculating the mean
        """
        avg = sum(self.data) / len(self.data)
        self.mean = avg
        print(self.mean)
    

    